@@ -86,6 +86,7 @@ extern int UseFrameLimit;
 extern uint32_t dwActFixes;
 extern float fFrameRateHz;
 extern int dwFrameRateTicks;
+extern int pl_frame_interval;
 
 // sound plugin
 extern int iUseReverb;
@@ -93,7 +94,8 @@ extern int iUseInterpolation;
 extern int iXAPitch;
 extern int iSPUIRQWait;
 extern int iUseTimer;
-
+extern char *cfile;
+	
 static void ChangeWorkingDirectory(char *exe)
 {
   s8 exepath[1024];
@@ -153,8 +155,7 @@ int main(int argc, char *argv[])
 	strcpy(Config.Cdr, "builtin_cdr");
 	strcpy(Config.Pad1, "builtin_pad");
 	strcpy(Config.Pad2, "builtin_pad");
-	
-	
+	int gles=0;
 	// read command line options
 	for (i = 1; i < argc; i++) {
 		     if (!strcmp(argv[i], "-psxout")) Config.PsxOut = 1;
@@ -183,19 +184,19 @@ int main(int argc, char *argv[])
 		UseFrameSkip=1;
 		fFrameRateHz = (tv_reg==1)?50.0f:  59.94f;
 		dwFrameRateTicks = (100000*100 / (unsigned long)(fFrameRateHz*100));
+		Config.PsxType=tv_reg;
+		pl_frame_interval = Config.PsxType ? 20000 : 16667;
+		g_opts |= 1;
 		}
 		}
-		else if (!strcmp(argv[i],"-sputhreaded")){
-			iUseTimer=1;
-		}
-		else if (!strcmp(argv[i],"-nosound")){
-				strcpy(Config.Spu, "spunull.so");
-		}
-		else if(!strcmp(argv[i], "-bdir"))	sprintf(Config.BiosDir, "%s", argv[++i]);
-		else if(!strcmp(argv[i], "-bios"))	sprintf(Config.Bios, "%s", argv[++i]);
-		else if (!strcmp(argv[i],"-gles")){
-		strcpy(Config.Gpu, "gpuGLES.so");
-		}
+		else if (!strcmp(argv[i],"-fullscreen"))		g_opts |= 2;
+		else if (!strcmp(argv[i],"-accel"))				g_opts |= 4;
+		else if (!strcmp(argv[i],"-sputhreaded"))		iUseTimer=1;
+		else if (!strcmp(argv[i],"-gles"))	{strcpy(Config.Gpu, "gpuGLES.so");gles=1;}
+		else if (!strcmp(argv[i],"-pcsxgpu"))	{strcpy(Config.Gpu, "gpuPCSX4ALL.so");}
+		else if(!strcmp(argv[i], "-bdir"))		sprintf(Config.BiosDir, "%s", argv[++i]);
+		else if(!strcmp(argv[i], "-bios"))		sprintf(Config.Bios, "%s", argv[++i]);
+		else if (!strcmp(argv[i],"-nosound"))	strcpy(Config.Spu, "spunull.so");
 		else if (!strcmp(argv[i], "-cdda"))		Config.Cdda = 1;
 		else if (!strcmp(argv[i], "-xa"))		Config.Xa = 1;
 		else if (!strcmp(argv[i], "-rcnt"))		Config.RCntFix = 1 ;
@@ -232,7 +233,8 @@ int main(int argc, char *argv[])
 		}
 	}
 
-
+		cfile=malloc(sizeof(char[255]));
+		sprintf (cfile, "%s.save.%s", file,loadst);
 	
 	
 	snprintf(Config.PatchesDir, sizeof(Config.PatchesDir), "/opt/maemo/usr/games" PATCHES_DIR);
@@ -243,7 +245,7 @@ int main(int argc, char *argv[])
 	chdir(plugin_default_dir);
 	g_free(plugin_default_dir);
 */
-
+if (gles==0)
 	hildon_init(&argc, &argv);
 	
 	if (cdfile)
@@ -284,13 +286,14 @@ int main(int argc, char *argv[])
 	}
 
 	// If a state has been specified, then load that
+	/*
 	if (loadst) {
 		char state_filename[MAXPATHLEN];
 		int ret = get_state_filename(state_filename, sizeof(state_filename), loadst - 1);
 		if (ret == 0)
 			ret = LoadState(state_filename);
 		printf("%s state %s\n", ret ? "failed to load" : "loaded", state_filename);
-	}
+	}*/
 
 
 	if (ready_to_go)
@@ -601,3 +604,5 @@ void SysCloseLibrary(void *lib) {
 	dlclose(lib);
 }
 
+
+
